@@ -54,11 +54,11 @@ namespace GPBoost {
 		* \param likelihood Likelihood function for the observed response variable. Default = "gaussian"
 		*/
 		LIGHTGBM_EXPORT REModel(data_size_t num_data,
-			const gp_id_t* cluster_ids_data,
+			const data_size_t* cluster_ids_data,
 			const char* re_group_data,
 			data_size_t num_re_group,
 			const double* re_group_rand_coef_data,
-			const int32_t* ind_effect_group_rand_coef,
+			const data_size_t* ind_effect_group_rand_coef,
 			data_size_t num_re_group_rand_coef,
 			data_size_t num_gp,
 			const double* gp_coords_data,
@@ -246,7 +246,7 @@ namespace GPBoost {
 		* \param covariate_data_pred Covariate data (=independent variables, features) for prediction
 		*/
 		void SetPredictionData(data_size_t num_data_pred,
-			const gp_id_t* cluster_ids_data_pred = nullptr, const char* re_group_data_pred = nullptr,
+			const data_size_t* cluster_ids_data_pred = nullptr, const char* re_group_data_pred = nullptr,
 			const double* re_group_rand_coef_data_pred = nullptr, double* gp_coords_data_pred = nullptr,
 			const double* gp_rand_coef_data_pred = nullptr, const double* covariate_data_pred = nullptr);
 
@@ -278,7 +278,7 @@ namespace GPBoost {
 		*/
 		void Predict(const double* y_obs, data_size_t num_data_pred, double* out_predict,
 			bool predict_cov_mat = false, bool predict_var = false, bool predict_response = false,
-			const gp_id_t* cluster_ids_data_pred = nullptr, const char* re_group_data_pred = nullptr, const double* re_group_rand_coef_data_pred = nullptr,
+			const data_size_t* cluster_ids_data_pred = nullptr, const char* re_group_data_pred = nullptr, const double* re_group_rand_coef_data_pred = nullptr,
 			double* gp_coords_data_pred = nullptr, const double* gp_rand_coef_data_pred = nullptr,
 			const double* cov_pars_pred = nullptr, const double* covariate_data_pred = nullptr,
 			bool use_saved_data = false, const char* vecchia_pred_type = nullptr, int num_neighbors_pred = -1,
@@ -325,7 +325,7 @@ namespace GPBoost {
 		double delta_rel_conv_ = 1.0e-6;
 		bool use_nesterov_acc_ = true;//only used for "gradient_descent"
 		int nesterov_schedule_version_ = 0;
-		string_t optimizer_cov_pars_ = "gradient_descent";//"gradient_descent", "fisher_scoring", or "nelder_mead" (The default = "fisher_scoring" is changed to "gradient_descent" for non-Gaussian data upon initialization)
+		string_t optimizer_cov_pars_ = "gradient_descent";//"gradient_descent", "fisher_scoring", or "nelder_mead"
 		vec_t coef_;//linear regression coefficients for fixed effects (in case there are any)
 		bool has_covariates_ = false;
 		bool coef_initialized_ = false;
